@@ -1,10 +1,10 @@
 package Module::CPANTS::Kwalitee::FindModules;
 use warnings;
 use strict;
-use File::Spec::Functions;
+use File::Spec::Functions qw(catfile);
 
-our $VERSION = '0.94';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.98';
+$VERSION =~ s/_//; ## no critic
 
 sub order { 30 }
 
@@ -13,86 +13,86 @@ sub order { 30 }
 ##################################################################
 
 sub analyse {
-    my $class=shift;
-    my $me=shift;
-    my $files=$me->d->{files_array} || [];
-  
+    my $class = shift;
+    my $me = shift;
+    my $files = $me->d->{files_array} || [];
+
     if ($me->d->{meta_yml} && $me->d->{meta_yml}{provides}) {
         my $provides = $me->d->{meta_yml}{provides};
-        while (my ($module,$data)=each %$provides) {
+        while (my ($module, $data) = each %$provides) {
             next unless ref $data eq ref {}; # ignore wrong format
-            my $file=$data->{file} || '';
-            my $found={
-                module=>$module,
-                file=>$file,
-                in_basedir=>0,
-                in_lib=>0,
+            my $file = $data->{file} || '';
+            my $found = {
+                module => $module,
+                file => $file,
+                in_basedir => 0,
+                in_lib => 0,
             };
             my $loc;
-            if ($file=~/^lib\W/) {
-                $found->{in_lib}=1;
+            if ($file =~ /^lib\W/) {
+                $found->{in_lib} = 1;
             }
-            elsif ($file !~/\//) {
-                $found->{in_basedir}=1;
+            elsif ($file !~ /\//) {
+                $found->{in_basedir} = 1;
             }
-            
-            push(@{$me->d->{modules}},$found);
+
+            push @{$me->d->{modules}}, $found;
             if (exists $me->d->{files_hash}{$file}) {
                 $me->d->{files_hash}{$file}{module} = $module;
             }
         }
     }
     else {
-        my %in_basedir= map {$_=>1} grep {/^[^\/]+\.pm$/} @$files;
-        
+        my %in_basedir =  map {$_ => 1} grep {/^[^\/]+\.pm$/} @$files;
+
         foreach my $file (@$files) {
-            next unless $file=~/\.pm$/;
-            next if $file=~m{^x?t/};
-            next if $file=~m{^test/};
-            next if $file=~m/^(bin|scripts?|ex|eg|examples?|samples?|demos?)\/\w/i;
-            next if $file=~m{^inc/};   # skip Module::Install stuff
-            next if $file=~m{^(local|perl5|fatlib)/};
+            next unless $file =~ /\.pm$/;
+            next if $file =~ m{^x?t/};
+            next if $file =~ m{^test/};
+            next if $file =~ m/^(bin|scripts?|ex|eg|examples?|samples?|demos?)\/\w/i;
+            next if $file =~ m{^inc/};   # skip Module::Install stuff
+            next if $file =~ m{^(local|perl5|fatlib)/};
 
             # proper file in lib/
-            if ($file=~m|^lib/(.*)\.pm$|) {
-                my $module=$1;
-                $module=~s|/|::|g;
-                push (@{$me->d->{modules}},{
-                    module=>$module,
-                    file=>$file,
-                    in_basedir=>0,
-                    in_lib=>1,
+            if ($file =~ m|^lib/(.*)\.pm$|) {
+                my $module = $1;
+                $module =~ s|/|::|g;
+                push (@{$me->d->{modules}}, {
+                    module => $module,
+                    file => $file,
+                    in_basedir => 0,
+                    in_lib => 1,
                 });
                 $me->d->{files_hash}{$file}{module} = $module;
             }
             else {
                 # open file and find first package
                 my $module;
-                my $max_lines_to_look_at=666;
-                open (my $fh,"<",catfile($me->distdir,$file)) || die "__PACKAGE__: Cannot open $file to find package declaration: $!";
+                my $max_lines_to_look_at = 666;
+                open (my $fh, "<", catfile($me->distdir, $file)) or die "__PACKAGE__: Cannot open $file to find package declaration: $!";
                 while (my $line = <$fh>) {
-                    next if $line =~/^\s*#/; # ignore comments
-                    if ($line =~/^\s*package\s*(.*?)\s*;/) {
-                        $module=$1;
+                    next if $line =~ /^\s*#/; # ignore comments
+                    if ($line =~ /^\s*package\s*(.*?)\s*;/) {
+                        $module = $1;
                         last;
                     }
-                    last if $line =~/^__(DATA|END)__/;
+                    last if $line =~ /^__(DATA|END)__/;
                     $max_lines_to_look_at--;
                     last unless $max_lines_to_look_at;
                 }
                 # try to guess from filename
                 unless ($module) {
-                    $file=~m|(.*)\.pm$|;
-                    $module=$1;
-                    $module=~s|^[a-z]+/||;  # remove lowercase prefixes which most likely are not part of the distname (but something like 'src/')
-                    $module=~s|/|::|g;
+                    $file =~ m|(.*)\.pm$|;
+                    $module = $1;
+                    $module =~ s|^[a-z]+/||;  # remove lowercase prefixes which most likely are not part of the distname (but something like 'src/')
+                    $module =~ s|/|::|g;
                 }
                 if ($module) {
                     push(@{$me->d->{modules}}, {
-                        module=>$module,
-                        file=>$file,
-                        in_basedir=> $in_basedir{$file} ? 1 : 0,
-                        in_lib=>0,
+                        module => $module,
+                        file => $file,
+                        in_basedir => $in_basedir{$file} ? 1 : 0,
+                        in_lib => 0,
                     });
                     $me->d->{files_hash}{$file}{module} = $module;
                 }
@@ -107,6 +107,13 @@ sub analyse {
         push @{$me->d->{included_modules} ||= []}, $module;
     }
 
+    if (exists $me->d->{modules}) {
+        $me->d->{modules} = [sort {$a->{module} cmp $b->{module}} @{$me->d->{modules}}];
+    }
+    if (exists $me->d->{included_modules}) {
+        $me->d->{included_modules} = [sort @{$me->d->{included_modules}}];
+    }
+
     return 1;
 }
 
@@ -119,26 +126,26 @@ sub analyse {
 sub kwalitee_indicators {
     return [
         {
-            name=>'proper_libs',
-            error=>q{There is more than one .pm file in the base dir, or the .pm files are not in lib/ directory.},
-            remedy=>q{Move your *.pm files in a directory named 'lib'. The directory structure should look like 'lib/Your/Module.pm' for a module named 'Your::Module'.},
+            name => 'proper_libs',
+            error => q{There is more than one .pm file in the base dir, or the .pm files are not in lib/ directory.},
+            remedy => q{Move your *.pm files in a directory named 'lib'. The directory structure should look like 'lib/Your/Module.pm' for a module named 'Your::Module'. If you need to provide additional files, e.g. for testing, that should not be considered for Kwalitee, then you should look at the 'provides' map in META.yml to limit the files scanned; or use the 'no_index' map to exclude parts of the distribution.},
             is_extra => 1,
-            code=>sub { 
-                my $d=shift;
+            code => sub {
+                my $d = shift;
                 my @modules = @{$d->{modules} || []};
                 return 1 unless @modules;
 
                 my @not_in_lib = grep { !$_->{in_lib} } @modules;
                 return 1 unless @not_in_lib;
 
-                my @in_basedir=grep { $_->{in_basedir} } @not_in_lib;
+                my @in_basedir = grep { $_->{in_basedir} } @not_in_lib;
                 return 1 if @in_basedir == 1;
 
                 $d->{error}{proper_libs} = join ', ', map {$_->{file}} @not_in_lib;
 
                 return 0;
             },
-            details=>sub {
+            details => sub {
                 my $d = shift;
                 my @modules = @{$d->{modules} || []};
                 return "No modules were found" unless @modules;
@@ -181,7 +188,7 @@ C<MCK::FindModules> first looks in C<basedir> and F<lib/> for C<*.pm> files. If
 
 =head3 kwalitee_indicators
 
-Returns the Kwalitee Indicators datastructure.
+Returns the Kwalitee Indicators data structure.
 
 =over
 
