@@ -4,8 +4,8 @@ use strict;
 use File::Spec::Functions qw(catfile);
 use Array::Diff;
 
-our $VERSION = '0.96';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.98';
+$VERSION =~ s/_//; ## no critic
 
 sub order { 100 }
 
@@ -14,16 +14,16 @@ sub order { 100 }
 ##################################################################
 
 sub analyse {
-    my $class=shift;
-    my $me=shift;
-    
-    my $distdir=$me->distdir;
-    my $manifest_file=catfile($distdir,'MANIFEST');
+    my $class = shift;
+    my $me = shift;
+
+    my $distdir = $me->distdir;
+    my $manifest_file = catfile($distdir, 'MANIFEST');
 
     if (-e $manifest_file) {
         # read manifest
-        open(my $fh, '<', $manifest_file) || die "cannot read MANIFEST $manifest_file: $!";
-        my @manifest;
+        open(my $fh, '<', $manifest_file) or die "cannot read MANIFEST $manifest_file: $!";
+        my %seen;
         while (<$fh>) {
             chomp;
             next if /^\s*#/; # discard pure comments
@@ -33,23 +33,32 @@ sub analyse {
                 s/\s.*$//;
             } # strip quotes and comments
             next unless $_; # discard blank lines
-            push(@manifest,$_);
+            $seen{$_}++;
         }
         close $fh;
 
-        @manifest=sort @manifest;
-        my @files=sort keys %{$me->d->{files_hash} || {}};
+        my @manifest = sort keys %seen;
+        my @files = sort keys %{$me->d->{files_hash} || {}};
+        my @dupes = grep {$seen{$_} > 1} @manifest;
 
-        my $diff=Array::Diff->diff(\@manifest,\@files);
-        if ($diff->count == 0) {
-            $me->d->{manifest_matches_dist}=1;
+        my $diff = Array::Diff->diff(\@manifest, \@files);
+        if ($diff->count == 0 && !@dupes) {
+            $me->d->{manifest_matches_dist} = 1;
         }
         else {
-            $me->d->{manifest_matches_dist}=0;
-            my @error = ( 
-                'MANIFEST ('.@manifest.') does not match dist ('.@files."):",
-                "Missing in MANIFEST: ".join(', ',@{$diff->added}), 
-                "Missing in Dist: " . join(', ',@{$diff->deleted}));
+            $me->d->{manifest_matches_dist} = 0;
+            my @error = (
+                'MANIFEST ('.(@manifest + @dupes).') does not match dist ('.@files."):",
+            );
+            if (my @added = @{$diff->added}) {
+                push @error, "Missing in MANIFEST: ".join(', ', @added);
+            }
+            if (my @deleted = @{$diff->deleted}) {
+                push @error, "Missing in Dist: " . join(', ', @deleted);
+            }
+            if (@dupes) {
+                push @error, "Duplicates in MANIFEST: " . join(', ', @dupes);
+            }
             $me->d->{error}{manifest_matches_dist} = \@error;
         }
 
@@ -65,8 +74,8 @@ sub analyse {
         }
     }
     else {
-        $me->d->{manifest_matches_dist}=0;
-        $me->d->{error}{manifest_matches_dist}=q{Cannot find MANIFEST in dist.};
+        $me->d->{manifest_matches_dist} = 0;
+        $me->d->{error}{manifest_matches_dist} = q{Cannot find MANIFEST in dist.};
     }
 }
 
@@ -77,11 +86,11 @@ sub analyse {
 sub kwalitee_indicators {
     return [
         {
-            name=>'manifest_matches_dist',
-            error=>q{MANIFEST does not match the contents of this distribution.},
-            remedy=>q{Run a proper command ("make manifest" or "./Build manifest", maybe with a force option), or use a distribution builder to generate the MANIFEST. Or update MANIFEST manually.},
-            code=>sub { shift->{manifest_matches_dist} ? 1 : 0 },
-            details=>sub {
+            name => 'manifest_matches_dist',
+            error => q{MANIFEST does not match the contents of this distribution.},
+            remedy => q{Run a proper command ("make manifest" or "./Build manifest", maybe with a force option), or use a distribution builder to generate the MANIFEST. Or update MANIFEST manually.},
+            code => sub { shift->{manifest_matches_dist} ? 1 : 0 },
+            details => sub {
                 my $d = shift;
                 my $error = $d->{error}{manifest_matches_dist};
                 return $error unless ref $error;
@@ -122,7 +131,7 @@ Check if MANIFEST and dist contents match.
 
 =head3 kwalitee_indicators
 
-Returns the Kwalitee Indicators datastructure.
+Returns the Kwalitee Indicators data structure.
 
 =over
 
