@@ -5,27 +5,26 @@ use File::Spec::Functions qw(catfile);
 use CPAN::Meta::YAML;
 use CPAN::Meta::Validator;
 use CPAN::Meta::Converter;
-use JSON::MaybeXS;
 use List::Util qw/first/;
 
-our $VERSION = '0.95';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.98';
+$VERSION =~ s/_//; ## no critic
 
 sub order { 10 }
 
-my $JSON_CLASS;
+my $JSON_DECODER = _load_json_decoder() || do { require JSON::PP; JSON::PP->can('decode_json') };
 
 ##################################################################
 # Analyse
 ##################################################################
 
 sub analyse {
-    my $class=shift;
-    my $me=shift;
-    my $distdir=$me->distdir;
-    my $meta_yml   = catfile($distdir,'META.yml');
-    my $meta_json  = catfile($distdir,'META.json');
-    my $mymeta_yml = catfile($distdir,'MYMETA.yml');
+    my $class = shift;
+    my $me = shift;
+    my $distdir = $me->distdir;
+    my $meta_yml   = catfile($distdir, 'META.yml');
+    my $meta_json  = catfile($distdir, 'META.json');
+    my $mymeta_yml = catfile($distdir, 'MYMETA.yml');
 
     # META.yml is not always the most preferred meta file,
     # but test it anyway because it may be broken sometimes.
@@ -59,7 +58,7 @@ sub analyse {
         }
     }
 
-    $me->d->{dynamic_config} = $me->d->{meta_yml}{dynamic_config} ? 1 : 0;
+    $me->d->{dynamic_config} = (!exists $me->d->{meta_yml}{dynamic_config} or $me->d->{meta_yml}{dynamic_config}) ? 1 : 0;
 }
 
 sub _analyse_yml {
@@ -69,16 +68,16 @@ sub _analyse_yml {
         # Broken META.yml may return a "YAML 1.0" string first.
         # eg. M/MH/MHASCH/Date-Gregorian-0.07.tar.gz
         if (@$meta > 1 or ref $meta->[0] ne ref {}) {
-            $me->d->{meta_yml}=first { ref $_ eq ref {} } @$meta;
-            $me->d->{error}{meta_yml_is_parsable}="multiple parts found in META.yml";
+            $me->d->{meta_yml} = first { ref $_ eq ref {} } @$meta;
+            $me->d->{error}{meta_yml_is_parsable} = "multiple parts found in META.yml";
         } else {
-            $me->d->{meta_yml}=$meta->[0];
-            $me->d->{meta_yml_is_parsable}=1;
+            $me->d->{meta_yml} = $meta->[0];
+            $me->d->{meta_yml_is_parsable} = 1;
         }
     };
     if (my $error = $@) {
         $error =~ s/ at \S+ line \d+.+$//s;
-        $me->d->{error}{meta_yml_is_parsable}=$error;
+        $me->d->{error}{meta_yml_is_parsable} = $error;
     }
     if ($me->d->{meta_yml}) {
         my ($spec, $error) = _validate_meta($me->d->{meta_yml});
@@ -93,7 +92,7 @@ sub _analyse_json {
     my $meta;
     eval {
         my $json = do { open my $fh, '<', $file or die "$file: $!"; local $/; <$fh> };
-        $meta = decode_json($json);
+        $meta = $JSON_DECODER->($json);
         $me->d->{meta_json_is_parsable} = 1;
     };
     if (my $error = $@) {
@@ -112,6 +111,12 @@ sub _analyse_json {
     }
 }
 
+sub _load_json_decoder {
+    my $json_class = $ENV{CPAN_META_JSON_BACKEND} || $ENV{PERL_JSON_BACKEND} || 'JSON::PP';
+    eval "require $json_class; 1" or return;
+    $json_class->can('decode_json');
+}
+
 sub _validate_meta {
     my $meta = shift;
     my $error;
@@ -131,58 +136,58 @@ sub _validate_meta {
 sub kwalitee_indicators{
     return [
         {
-            name=>'meta_yml_is_parsable',
-            error=>q{The META.yml file of this distribution could not be parsed by the version of CPAN::Meta::YAML.pm CPANTS is using.},
-            remedy=>q{Upgrade your YAML generator so it produces valid YAML.},
-            code=>sub {
+            name => 'meta_yml_is_parsable',
+            error => q{The META.yml file of this distribution could not be parsed by the version of CPAN::Meta::YAML.pm CPANTS is using.},
+            remedy => q{Upgrade your YAML generator so it produces valid YAML.},
+            code => sub {
                 my $d = shift;
                 !$d->{error}{meta_yml_is_parsable} ? 1 : 0
             },
-            details=>sub {
+            details => sub {
                 my $d = shift;
                 $d->{error}{meta_yml_is_parsable};
             },
         },
         {
-            name=>'meta_json_is_parsable',
-            error=>q{The META.json file of this distribution could not be parsed by the version of JSON parser CPANTS is using.},
-            remedy=>q{Upgrade your META.json generator so it produces valid JSON.},
-            code=>sub {
+            name => 'meta_json_is_parsable',
+            error => q{The META.json file of this distribution could not be parsed by the version of JSON parser CPANTS is using.},
+            remedy => q{Upgrade your META.json generator so it produces valid JSON.},
+            code => sub {
                 my $d = shift;
                 !$d->{error}{meta_json_is_parsable} ? 1 : 0
             },
-            details=>sub {
+            details => sub {
                 my $d = shift;
                 $d->{error}{meta_json_is_parsable};
             },
         },
         {
-            name=>'meta_yml_has_provides',
-            is_experimental=>1,
-            error=>q{This distribution does not have a list of provided modules defined in META.yml.},
-            remedy=>q{Add all modules contained in this distribution to the META.yml field 'provides'. Module::Build or Dist::Zilla::Plugin::MetaProvides do this automatically for you.},
-            code=>sub { 
-                my $d=shift;
+            name => 'meta_yml_has_provides',
+            is_experimental => 1,
+            error => q{This distribution does not have a list of provided modules defined in META.yml.},
+            remedy => q{Add all modules contained in this distribution to the META.yml field 'provides'. Module::Build or Dist::Zilla::Plugin::MetaProvides do this automatically for you.},
+            code => sub {
+                my $d = shift;
                 return 1 if !$d->{meta_yml};
                 return 1 if $d->{meta_yml}{provides};
                 return 0;
             },
-            details=>sub {
+            details => sub {
                 my $d = shift;
                 return "No META.yml." unless $d->{meta_yml};
                 return q{No "provides" was found in META.yml.};
             },
         },
         {
-            name=>'meta_yml_conforms_to_known_spec',
-            error=>q{META.yml does not conform to any recognised META.yml Spec.},
-            remedy=>q{Take a look at the META.yml Spec at http://module-build.sourceforge.net/META-spec-v1.4.html (for version 1.4) or http://search.cpan.org/perldoc?CPAN::Meta::Spec (for version 2), and change your META.yml accordingly.},
-            code=>sub {
-                my $d=shift;
+            name => 'meta_yml_conforms_to_known_spec',
+            error => q{META.yml does not conform to any recognised META.yml Spec.},
+            remedy => q{Take a look at the META.yml Spec at https://metacpan.org/pod/CPAN::Meta::History::Meta_1_4 (for version 1.4) or https://metacpan.org/pod/CPAN::Meta::Spec (for version 2), and change your META.yml accordingly.},
+            code => sub {
+                my $d = shift;
                 return 0 if $d->{error}{meta_yml_conforms_to_known_spec};
                 return 1;
             },
-            details=>sub {
+            details => sub {
                 my $d = shift;
                 return "No META.yml." unless $d->{meta_yml};
                 return "META.yml is broken." unless $d->{meta_yml_is_parsable};
@@ -190,33 +195,33 @@ sub kwalitee_indicators{
             },
         },
         {
-            name=>'meta_json_conforms_to_known_spec',
-            error=>q{META.json does not conform to any recognised META Spec.},
-            remedy=>q{Take a look at the META.json Spec at http://module-build.sourceforge.net/META-spec-v1.4.html (for version 1.4) or http://search.cpan.org/perldoc?CPAN::Meta::Spec (for version 2), and change your META.json accordingly.},
-            code=>sub {
-                my $d=shift;
+            name => 'meta_json_conforms_to_known_spec',
+            error => q{META.json does not conform to any recognised META Spec.},
+            remedy => q{Take a look at the META.json Spec at https://metacpan.org/pod/CPAN::Meta::History::Meta_1_4 (for version 1.4) or https://metacpan.org/pod/CPAN::Meta::Spec (for version 2), and change your META.json accordingly.},
+            code => sub {
+                my $d = shift;
                 return 0 if $d->{error}{meta_json_is_parsable};
                 return 0 if $d->{error}{meta_json_conforms_to_known_spec};
                 return 1;
             },
-            details=>sub {
+            details => sub {
                 my $d = shift;
                 return "META.json is broken." unless $d->{meta_json_is_parsable};
                 return $d->{error}{meta_json_conforms_to_known_spec};
             },
         },
         {
-            name=>'meta_yml_declares_perl_version',
-            error=>q{This distribution does not declare the minimum perl version in META.yml.},
-            is_extra=>1,
-            remedy=>q{If you are using Build.PL define the {requires}{perl} = VERSION field. If you are using MakeMaker (Makefile.PL) you should upgrade ExtUtils::MakeMaker to 6.48 and use MIN_PERL_VERSION parameter. Perl::MinimumVersion can help you determine which version of Perl your module needs.},
-            code=>sub { 
-                my $d=shift;
-                my $yaml=$d->{meta_yml};
+            name => 'meta_yml_declares_perl_version',
+            error => q{This distribution does not declare the minimum perl version in META.yml.},
+            is_extra => 1,
+            remedy => q{If you are using Build.PL define the {requires}{perl} = VERSION field. If you are using MakeMaker (Makefile.PL) you should upgrade ExtUtils::MakeMaker to 6.48 and use MIN_PERL_VERSION parameter. Perl::MinimumVersion can help you determine which version of Perl your module needs.},
+            code => sub {
+                my $d = shift;
+                my $yaml = $d->{meta_yml};
                 return 1 unless $yaml;
                 return ref $yaml->{requires} eq ref {} && $yaml->{requires}{perl} ? 1 : 0;
             },
-            details=>sub {
+            details => sub {
                 my $d = shift;
                 my $yaml = $d->{meta_yml};
                 return "No META.yml." unless $yaml;
@@ -225,17 +230,17 @@ sub kwalitee_indicators{
             },
         },
         {
-            name=>'meta_yml_has_repository_resource',
-            is_experimental=>1,
-            error=>q{This distribution does not have a link to a repository in META.yml.},
-            remedy=>q{Add a 'repository' resource to the META.yml via 'meta_add' accessor (for Module::Build) or META_ADD parameter (for ExtUtils::MakeMaker).},
-            code=>sub { 
-                my $d=shift;
+            name => 'meta_yml_has_repository_resource',
+            is_experimental => 1,
+            error => q{This distribution does not have a link to a repository in META.yml.},
+            remedy => q{Add a 'repository' resource to the META.yml via 'meta_add' accessor (for Module::Build) or META_ADD parameter (for ExtUtils::MakeMaker).},
+            code => sub {
+                my $d = shift;
                 my $yaml = $d->{meta_yml};
                 return 1 unless $yaml;
                 return ref $yaml->{resources} eq ref {} && $yaml->{resources}{repository} ? 1 : 0;
             },
-            details=>sub {
+            details => sub {
                 my $d = shift;
                 my $yaml = $d->{meta_yml};
                 return "No META.yml." unless $yaml;
@@ -259,7 +264,7 @@ Module::CPANTS::Kwalitee::MetaYML - Checks data available in META.yml
 
 =head1 SYNOPSIS
 
-Checks various pieces of information in META.yml
+Checks various pieces of information in F<META.yml>
 
 =head1 DESCRIPTION
 
@@ -269,8 +274,8 @@ Checks various pieces of information in META.yml
 
 Defines the order in which Kwalitee tests should be run.
 
-Returns C<10>. MetaYML should be checked earlier than Files to
-handle no_index correctly.
+Returns C<10>. C<MetaYML> should be checked earlier than C<Files> to
+handle C<no_index> correctly.
 
 =head3 analyse
 
@@ -278,7 +283,7 @@ C<MCK::MetaYML> checks C<META.yml>.
 
 =head3 kwalitee_indicators
 
-Returns the Kwalitee Indicators datastructure.
+Returns the Kwalitee Indicators data structure.
 
 =over
 
