@@ -2,8 +2,8 @@ package Module::CPANTS::Kwalitee::Repackageable;
 use warnings;
 use strict;
 
-our $VERSION = '0.95';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.98';
+$VERSION =~ s/_//; ## no critic
 
 sub order { 900 }
 
@@ -12,14 +12,14 @@ sub order { 900 }
 ##################################################################
 
 sub analyse {
-    my $class=shift;
-    my $me=shift;
+    my $class = shift;
+    my $me = shift;
 
     # NOTE: The analysis/metric in this module has moved to
     # Module::CPANTS::SiteKwalitee.
 
     # Note also that this stub should not be removed so that
-    # this can replace the old ::Signature module, and the old
+    # this can replace the old ::Repackageable module, and the old
     # metrics will not be loaded while loading plugins.
 
     return;
@@ -46,7 +46,7 @@ Module::CPANTS::Kwalitee::Repackageable - Checks for various signs that make a m
 
 =head1 SYNOPSIS
 
-There are several aggregate metrics in here.
+The metrics in this module have moved to L<Module::CPANTS::SiteKwalitee|https://github.com/cpants/Module-CPANTS-SiteKwalitee>.
 
 =head1 DESCRIPTION
 
@@ -60,7 +60,7 @@ Defines the order in which Kwalitee tests should be run.
 
 =head3 kwalitee_indicators
 
-Returns the Kwalitee Indicators datastructure.
+Returns the Kwalitee Indicators data structure.
 
 =head1 SEE ALSO
 
